@@ -11,7 +11,7 @@ class cdcc_refund(Variable):
     reference = "https://www.law.cornell.edu/uscode/text/26/21#g_1"
 
     def formula(tax_unit, period, parameters):
-        cdcc = parameters(period).irs.credits.cdcc
+        cdcc = parameters(period).gov.irs.credits.cdcc
         if cdcc.refundable:
             return tax_unit("cdcc", period)
         else:
