@@ -13,5 +13,5 @@ class is_ca_cvrp_normal_rebate_eligible(Variable):
         # AGI must be less than the threshold.
         agi = person.tax_unit("adjusted_gross_income", period)
         filing_status = person.tax_unit("filing_status", period)
-        caps = parameters(period).states.ca.calepa.carb.cvrp.income_cap
+        caps = parameters(period).gov.states.ca.calepa.carb.cvrp.income_cap
         return agi <= caps[filing_status]
